#
# spec file for package python-EditorConfig
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname editorconfig-core-py
Name:           python-EditorConfig
Version:        0.12.4+git.1707726233.2740dee
Release:        2.3
Summary:        File Locator and Interpreter for Python
License:        BSD-2-Clause AND Python-2.0
URL:            https://editorconfig.org
Source0:        %{modname}-%{version}.tar.xz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
EditorConfig Python Core provides the same functionality as the
EditorConfig C Core. EditorConfig Python core can be used as a
command line program or as an importable library.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# remove executable that is already supplied by the editorconfig package
rm -rf %{buildroot}%{_bindir}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONDONTWRITEBYTECODE=1
# Still not resolved issues with tests, gh#editorconfig/editorconfig-core-py#37
%{python_expand cmake .
export PYTHONPATH=%{buildroot}%{$python_sitelib}
ctest -VV --output-on-failure . || /bin/true
}

%files %{python_files}
%license LICENSE.* COPYING
%doc README.rst
%{python_sitelib}/editorconfig
%{python_sitelib}/EditorConfig-%(echo %{version}|cut -d+ -f 1)*-info

%changelog
* Sun Aug  4 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Don't write python bytecode in tests for reproducible builds
* Tue Jul 30 2024 Matej Cepl <mcepl@cepl.eu>
- Update to editorconfig-core-py-0.12.4+git.1707726233.2740dee:
  * Bump to v0.12.4 (#50)
  * fix: only support Python3 (#48)
  * Move the most of metadata into `setup.cfg` supported since Dec 2015. (#44)
  * Add additional URLs into package metadata. (#43)
  * Fix cloning submodules (#40)
* Sat Sep 18 2021 mcepl@cepl.eu
- Update to version 0.12.3+git.1630438300.f43312a:
  * Add PYTHONPATH to the instructions (#38)
* Fri Aug 27 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.12.3
  * Update 0.12.3 to final version
  * Add Python 3.9 support
  * Fix fnmatch adjacent nested curly braces (#33)
  * tests: bump to master (#32)
  * editorconfig as a module (#31)
  * setup.py: read version without installing (#30)
  * travis: support Python 3.8
  * Fix deprecation warnings coming with Python 3.7
  * Add (c) to copyright notices per @xuhdev's request
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.12.2:
  * no upstream changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Mar  3 2017 aloisio@gmx.com
- Converted to single-spec
- Dropped rpmlintrc
- Dropped executable already supplied by the editorconfig
  package
* Thu Feb 16 2017 aloisio@gmx.com
- Renamed executable to avoid conflict with the editorconfig
  package
* Tue Feb 14 2017 aloisio@gmx.com
- Added python3-EditorConfig-rpmlintrc as source file
* Thu Feb  2 2017 aloisio@gmx.com
- Initial package (0.12.1)
